@@ -1,4 +1,7 @@
 package DateTime::Format::Strptime;
+BEGIN {
+  $DateTime::Format::Strptime::VERSION = '1.5000';
+}
 
 use strict;
 
@@ -10,10 +13,9 @@ use Carp;
 
 use Exporter;
 use vars
-    qw( $VERSION @ISA @EXPORT @EXPORT_OK %ZONEMAP %FORMATS $CROAK $errmsg);
+    qw( @ISA @EXPORT @EXPORT_OK %ZONEMAP %FORMATS $CROAK $errmsg);
 
 @ISA       = 'Exporter';
-$VERSION   = '1.2000';
 @EXPORT_OK = qw( &strftime &strptime );
 @EXPORT    = ();
 
@@ -121,6 +123,7 @@ $VERSION   = '1.2000';
     'Y'      => '-1200',     'YAKST'  => '+1000',     'YAKT'   => '+0900',
     'YAPT'   => '+1000',     'YDT'    => '-0800',     'YEKST'  => '+0600',
     'YEKT'   => '+0500',     'YST'    => '-0900',     'Z'      => '+0000',
+    'UTC'    => '+0000',
 );
 
 sub new {
@@ -1079,7 +1082,7 @@ DateTime::Format::Strptime - Parse and format strp and strf time patterns
 
 =head1 VERSION
 
-version 1.3000
+version 1.5000
 
 =head1 SYNOPSIS
 
@@ -1429,7 +1432,7 @@ L<perl>, L<DateTime>, L<DateTime::TimeZone>, L<DateTime::Locale>
 
 =head1 AUTHOR
 
-  Dave Rolsky <autarch@urth.org>
+Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
